pytest_pyramid
==============

pytest_pyramid provides basic fixtures for testing pyramid applications with pytest test suite.



.. toctree::
   :maxdepth: 2

   usage
   api
   changelog
   authors

License
-------

Copyright (c) 2014 by pytest_pyramid authors and contributors. See :ref:`authors`

This module is part of pytest_pyramid and is released under
the MIT License (MIT): http://opensource.org/licenses/MIT
